import React, { useEffect, useState } from "react";
import CustomColorPicker from "@/components/CustomColorPicker";
import {
  Checkbox,
  InputNumber,
  Select,
  Input,
  Divider,
} from "antd";
import { useModel } from "umi";

export default function PageStyle() {
  const { pageState, onChangePageSettings } = useModel("appModel");

  return (
    <div>
      <section className="px-16px">
        <div className="flex-1 font-bold">背景样式</div>
        <div className="flex items-center justify-between px-0px py-8px gap-16px">
          <Select
            className="flex-1"
            options={[
              { label: "纯色", value: 1 },
              { label: "图片", value: 2 },
            ]}
          />
          <CustomColorPicker
            color={pageState.backgroundColor}
            onChange={(color) => onChangePageSettings("backgroundColor", color)}
          />
        </div>
        <div className="flex justify-between items-center gap-16px">
          <span>图片地址</span>
          <Input
            className="flex-1"
            placeholder="请输入图片地址"
          />
        </div>
        <Divider className="my-8px" />
        <div className="flex-1 font-bold">主题间距</div>
        <div className="text-12px color-#6c7d8f my-4px">分支主题</div>
        <div className="flex justify-between gap-8px">
          <InputNumber
            className="flex-1"
            value={pageState.width}
            suffix="W"
            step={1}
            min={10}
            max={2000}
            formatter={(val) => `${val}px`}
            onChange={(val) => onChangePageSettings("width", val)}
          />
          <InputNumber
            className="flex-1"
            value={pageState.width}
            suffix="W"
            step={1}
            min={10}
            max={2000}
            formatter={(val) => `${val}px`}
            onChange={(val) => onChangePageSettings("width", val)}
          />
        </div>
        <div className="text-12px color-#6c7d8f my-4px">子主题</div>
        <div className="flex justify-between gap-8px">
          <InputNumber
            className="flex-1"
            value={pageState.width}
            suffix="W"
            step={1}
            min={10}
            max={2000}
            formatter={(val) => `${val}px`}
            onChange={(val) => onChangePageSettings("width", val)}
          />
          <InputNumber
            className="flex-1"
            value={pageState.width}
            suffix="W"
            step={1}
            min={10}
            max={2000}
            formatter={(val) => `${val}px`}
            onChange={(val) => onChangePageSettings("width", val)}
          />
        </div>
      </section>
      <section className="px-16px my-8px">
        <div>
          <Checkbox
            checked={pageState.grid}
            onChange={(e) => onChangePageSettings("grid", e.target.checked)}
          >
            <span className="font-bold">同级主题对齐</span>
          </Checkbox>
        </div>
      </section>
      <Divider className="my-8px" />
      <section className="px-16px">
        <Checkbox
          className="mb-8px"
          checked={pageState.watermark}
          onChange={(e) => onChangePageSettings("watermark", e.target.checked)}
        >
          <span className="font-bold">显示水印</span>
        </Checkbox>
        <Input
          value={pageState.watermarkText}
          placeholder="不超过15字，回车保存"
          maxLength={15}
          onChange={(e) =>
            onChangePageSettings("watermarkText", e.target.value)
          }
        />
      </section>
    </div>
  );
}
